summaryrefslogtreecommitdiffstats
path: root/ash/system/tray
diff options
context:
space:
mode:
authortreib@chromium.org <treib@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-18 13:26:57 +0000
committertreib@chromium.org <treib@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-18 13:26:57 +0000
commit933cc2e2d4f2335ffec0a90ddf714f5ef416c78f (patch)
tree00f7f35568d1e8e128306a003b8f19249784c530 /ash/system/tray
parent5c277ba487161758226fa835eacb00d55322dad5 (diff)
downloadchromium_src-933cc2e2d4f2335ffec0a90ddf714f5ef416c78f.zip
chromium_src-933cc2e2d4f2335ffec0a90ddf714f5ef416c78f.tar.gz
chromium_src-933cc2e2d4f2335ffec0a90ddf714f5ef416c78f.tar.bz2
Rename "managed (mode|user)" to "supervised user" (part 7)
Followup to https://codereview.chromium.org/384023002/ This CL renames ChromeOS-specific code. Still missing: - ChromeOS-specific resource IDs (strings and images) - JavaScript, HTML, CSS - The global ENABLE_MANAGED_USERS define TBR=atwilson@chromium.org (c/b/signin) TBR=nkostylev@chromium.org (c/b/chromeos) TBR=noms@chromium.org (c/b/profiles) TBR=oshima@chromium.org (ash and c/b/ui/ash) All TBRs are simple renamings. BUG=385113 Review URL: https://codereview.chromium.org/393343002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@284078 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/system/tray')
-rw-r--r--ash/system/tray/default_system_tray_delegate.cc8
-rw-r--r--ash/system/tray/default_system_tray_delegate.h8
-rw-r--r--ash/system/tray/system_tray.cc4
-rw-r--r--ash/system/tray/system_tray_delegate.h18
4 files changed, 19 insertions, 19 deletions
diff --git a/ash/system/tray/default_system_tray_delegate.cc b/ash/system/tray/default_system_tray_delegate.cc
index eae6bd3..839575bef 100644
--- a/ash/system/tray/default_system_tray_delegate.cc
+++ b/ash/system/tray/default_system_tray_delegate.cc
@@ -71,17 +71,17 @@ const base::string16 DefaultSystemTrayDelegate::GetEnterpriseMessage() const {
}
const std::string
-DefaultSystemTrayDelegate::GetLocallyManagedUserManager() const {
+DefaultSystemTrayDelegate::GetSupervisedUserManager() const {
return std::string();
}
const base::string16
-DefaultSystemTrayDelegate::GetLocallyManagedUserManagerName()
+DefaultSystemTrayDelegate::GetSupervisedUserManagerName()
const {
return base::string16();
}
-const base::string16 DefaultSystemTrayDelegate::GetLocallyManagedUserMessage()
+const base::string16 DefaultSystemTrayDelegate::GetSupervisedUserMessage()
const {
return base::string16();
}
@@ -145,7 +145,7 @@ void DefaultSystemTrayDelegate::ShowPublicAccountInfo() {
void DefaultSystemTrayDelegate::ShowEnterpriseInfo() {
}
-void DefaultSystemTrayDelegate::ShowLocallyManagedUserInfo() {
+void DefaultSystemTrayDelegate::ShowSupervisedUserInfo() {
}
void DefaultSystemTrayDelegate::ShowUserLogin() {
diff --git a/ash/system/tray/default_system_tray_delegate.h b/ash/system/tray/default_system_tray_delegate.h
index 7586932..84594bd 100644
--- a/ash/system/tray/default_system_tray_delegate.h
+++ b/ash/system/tray/default_system_tray_delegate.h
@@ -25,10 +25,10 @@ class ASH_EXPORT DefaultSystemTrayDelegate : public SystemTrayDelegate {
virtual void ChangeProfilePicture() OVERRIDE;
virtual const std::string GetEnterpriseDomain() const OVERRIDE;
virtual const base::string16 GetEnterpriseMessage() const OVERRIDE;
- virtual const std::string GetLocallyManagedUserManager() const OVERRIDE;
- virtual const base::string16 GetLocallyManagedUserManagerName() const
+ virtual const std::string GetSupervisedUserManager() const OVERRIDE;
+ virtual const base::string16 GetSupervisedUserManagerName() const
OVERRIDE;
- virtual const base::string16 GetLocallyManagedUserMessage() const OVERRIDE;
+ virtual const base::string16 GetSupervisedUserMessage() const OVERRIDE;
virtual bool SystemShouldUpgrade() const OVERRIDE;
virtual base::HourClockType GetHourClockType() const OVERRIDE;
virtual void ShowSettings() OVERRIDE;
@@ -47,7 +47,7 @@ class ASH_EXPORT DefaultSystemTrayDelegate : public SystemTrayDelegate {
virtual void ShowAccessibilitySettings() OVERRIDE;
virtual void ShowPublicAccountInfo() OVERRIDE;
virtual void ShowEnterpriseInfo() OVERRIDE;
- virtual void ShowLocallyManagedUserInfo() OVERRIDE;
+ virtual void ShowSupervisedUserInfo() OVERRIDE;
virtual void ShowUserLogin() OVERRIDE;
virtual bool ShowSpringChargerReplacementDialog() OVERRIDE;
virtual bool IsSpringChargerReplacementDialogVisible() OVERRIDE;
diff --git a/ash/system/tray/system_tray.cc b/ash/system/tray/system_tray.cc
index 5c6af2c..b4ba58e 100644
--- a/ash/system/tray/system_tray.cc
+++ b/ash/system/tray/system_tray.cc
@@ -47,7 +47,6 @@
#include "ash/system/chromeos/audio/tray_audio_chromeos.h"
#include "ash/system/chromeos/brightness/tray_brightness.h"
#include "ash/system/chromeos/enterprise/tray_enterprise.h"
-#include "ash/system/chromeos/managed/tray_locally_managed_user.h"
#include "ash/system/chromeos/network/tray_network.h"
#include "ash/system/chromeos/network/tray_sms.h"
#include "ash/system/chromeos/network/tray_vpn.h"
@@ -57,6 +56,7 @@
#include "ash/system/chromeos/screen_security/screen_share_tray_item.h"
#include "ash/system/chromeos/session/tray_session_length_limit.h"
#include "ash/system/chromeos/settings/tray_settings.h"
+#include "ash/system/chromeos/supervised/tray_supervised_user.h"
#include "ash/system/chromeos/tray_caps_lock.h"
#include "ash/system/chromeos/tray_display.h"
#include "ash/system/chromeos/tray_tracing.h"
@@ -173,7 +173,7 @@ void SystemTray::CreateItems(SystemTrayDelegate* delegate) {
#if defined(OS_CHROMEOS)
AddTrayItem(new TraySessionLengthLimit(this));
AddTrayItem(new TrayEnterprise(this));
- AddTrayItem(new TrayLocallyManagedUser(this));
+ AddTrayItem(new TraySupervisedUser(this));
AddTrayItem(new TrayIME(this));
AddTrayItem(tray_accessibility_);
AddTrayItem(new TrayTracing(this));
diff --git a/ash/system/tray/system_tray_delegate.h b/ash/system/tray/system_tray_delegate.h
index 73fd0ca..dffa9f1 100644
--- a/ash/system/tray/system_tray_delegate.h
+++ b/ash/system/tray/system_tray_delegate.h
@@ -140,15 +140,15 @@ class ASH_EXPORT SystemTrayDelegate {
// Returns notification for enterprise enrolled devices.
virtual const base::string16 GetEnterpriseMessage() const = 0;
- // Returns the display email of user that manages current
- // locally managed user.
- virtual const std::string GetLocallyManagedUserManager() const = 0;
+ // Returns the display email of the user that manages the current supervised
+ // user.
+ virtual const std::string GetSupervisedUserManager() const = 0;
- // Returns the name of user that manages current locally managed user.
- virtual const base::string16 GetLocallyManagedUserManagerName() const = 0;
+ // Returns the name of the user that manages the current supervised user.
+ virtual const base::string16 GetSupervisedUserManagerName() const = 0;
- // Returns notification for locally managed users.
- virtual const base::string16 GetLocallyManagedUserMessage() const = 0;
+ // Returns the notification for supervised users.
+ virtual const base::string16 GetSupervisedUserMessage() const = 0;
// Returns whether a system upgrade is available.
virtual bool SystemShouldUpgrade() const = 0;
@@ -206,8 +206,8 @@ class ASH_EXPORT SystemTrayDelegate {
// Shows information about enterprise enrolled devices.
virtual void ShowEnterpriseInfo() = 0;
- // Shows information about locally managed users.
- virtual void ShowLocallyManagedUserInfo() = 0;
+ // Shows information about supervised users.
+ virtual void ShowSupervisedUserInfo() = 0;
// Shows login UI to add other users to this session.
virtual void ShowUserLogin() = 0;